# peppa8
<p align="center">
<img width="30%" src="https://github.com/skhortiuk/peppa8/blob/master/static/peppa.jpg?raw=True">
</p>


# How it works
Runs autopep8 on your diff from git.

# Installation
```shell script
pip install peppa8
```

# How to run
```shell script
peppa8
```

# Example output
<p align="center">
<img width="100%" src="https://github.com/skhortiuk/peppa8/blob/master/static/example.png?raw=True">
</p>

